//+------------------------------------------------------------------+
//|                                          GQGenerateRecToExel.mq5 |
//|                              Copyright  2015, Vladimir Karputov |
//|                                           http://wmua.ru/slesar/ |
//+------------------------------------------------------------------+
#property copyright "Copyright  2015, Vladimir Karputov"
#property link      "http://wmua.ru/slesar/"
#property version   "1.00"
#property description "Output values of the normal distribution to the file."
#property script_show_inputs
#include <Math\Alglib\alglib.mqh>
//--- input
input uint  radius=30;              // blur radius
//+------------------------------------------------------------------+
//| Script program start function                                    |
//+------------------------------------------------------------------+
void OnStart()
  {
//---
   int         NNodes=(int)radius*2+1;
   double      weights[];                    // array of weights
//---
   if(!GetQuadratureWeights(1,NNodes,weights))
      return;
//---
   int      file_handle;
   string   fileName="GQGenerateRecToExel.csv";
   file_handle=FileOpen(fileName,FILE_READ|FILE_WRITE|FILE_CSV);
   if(file_handle!=INVALID_HANDLE)
     {
      //--- write the name of the column
      FileWrite(file_handle,GetText(NNodes));
     }
   else
      PrintFormat("File %s open failed, error = %d",fileName,GetLastError());
//---
   for(int i=0;i<NNodes;i++)
     {
      FileWrite(file_handle,DoubleToString(weights[i],6));
     }
//--- close the file
   FileClose(file_handle);;
  }
//+------------------------------------------------------------------+
//| Gets array of quadrature weights                                 |
//+------------------------------------------------------------------+
bool GetQuadratureWeights(const double mu0,const int n,double &w[])
  {
   CAlglib alglib;            // static member of class CAlglib
   double      alp[];         // array alpha coefficients 
   double      bet[];         // array beta coefficients 
   ArrayResize(alp,n);
   ArrayResize(bet,n);
   ArrayInitialize(alp,1.0);  // initializes a numeric array alpha
   ArrayInitialize(bet,1.0);  // initializes a numeric array beta
//---
   double      out_x[];
   int         inf=0;
//| Info    -   error code:                                          |
//|                 * -3    internal eigenproblem solver hasn't      |
//|                         converged                                |
//|                 * -2    Beta[i]<=0                               |
//|                 * -1    incorrect N was passed                   |
//|                 *  1    OK                                       |
   alglib.GQGenerateRec(alp,bet,mu0,n,inf,out_x,w);
   if(inf!=1)
     {
      Print("Call error in CGaussQ::GQGenerateRec");
      return(false);
     }
   return(true);
  }
//+------------------------------------------------------------------+
//| Comment depending on the language of the terminal                |
//+------------------------------------------------------------------+
string GetText(const int nodes)
  {
   string text="";
   string lang=TerminalInfoString(TERMINAL_LANGUAGE);
   if(lang=="English")
     {
      text="Normal distribution for "+IntegerToString(nodes)+" nodes";
      return(text);
     }
   if(lang=="Russian")
     {
      text="   "+IntegerToString(nodes)+" ";
      return(text);
     }
   text="Normal distribution for "+IntegerToString(nodes)+" nodes";
//--- ok
   return(text);
  }
//+------------------------------------------------------------------+
